#!/bin/bash

usageEcho1="Usage: disk-set.sh [ linux / windows ] launch {hostName} {numberOfDisks} {mountPoint1} {mountPoint2}.."
usageEcho2="Usage: disk-set.sh [ linux / windows ] resize {hostName} {mountPoint}"
usageEcho3="Usage: disk-set.sh [ linux / windows ] delete {hostName} {mountPoint}"
saltHome=/salt
saltDiskHome=$saltHome/disks
saltDataHome=$saltDiskHome/data
saltDiskUrl=salt://disks
saltDataUrl=$saltDiskUrl/data
winPrepareTemplate1=$saltDiskUrl/win-prepare.bat
winPrepareTemplate2=$saltDiskUrl/win-prepare.txt
winLaunchTemplate=$saltDiskHome/win-launch.txt
winResizeTemplate1=$saltDiskHome/win-resize.bat
winResizeTemplate2=$saltDiskUrl/win-resize.txt
winDeleteTemplate1=$saltDiskHome/win-delete.bat
winDeleteTemplate2=$saltDiskUrl/win-delete.txt
osType=$1
diskMethod=$2
hostName=$3
fileName=`head /dev/urandom | tr -dc A-Za-z0-9 | head -c 10 ; echo ''`


case $osType in
    linux)
        case $diskMethod in
            launch)
            ;;
            resize)
            ;;
            delete)
            ;;
            *)
                echo $usageEcho1
                echo $usageEcho2
                echo $usageEcho3
        esac
    ;;
    windows)
        case $diskMethod in
            launch)
                diskCount=$4
                salt "$hostName" cp.get_file $winPrepareTemplate1 'C:\Windows\Temp\prepare.bat' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskLaunch : cp.get_file : prepare.bat : failed"
                    exit 1
                else
                    echo "DiskLaunch : cp.get_file : prepare.bat : success"
                fi 
                salt "$hostName" cp.get_file $winPrepareTemplate2 'C:\Windows\Temp\prepare.txt' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskLaunch : cp.get_file : prepare.txt : failed"
                    exit 1
                else
                    echo "DiskLaunch : cp.get_file : prepare.txt : success"
                fi 
                salt "$hostName" cmd.run 'diskpart /s C:\Windows\Temp\prepare.bat' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskLaunch : cmd.run : prepare.bat : failed"
                    exit 1
                else
                    echo "DiskLaunch : cmd.run : prepare.bat : success"
                fi

                c=0
                for i in $*;do
                    if [[ "$i" =~ [A-Z] ]];then
                        sed "s/{diskNumber}/$((c+=1))/gi" $winLaunchTemplate >> $saltDataHome/$fileName\.txt
                        sed -i "s/{mountPoint}/$i/gi" $saltDataHome/$fileName\.txt
                    fi
                done
                salt "$hostName" cp.get_file $saltDataUrl/$fileName\.txt 'C:\Windows\Temp\launch.txt' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskLaunch : cp.get_file : launch.txt : failed"
                    exit 1
                else
                    echo "DiskLaunch : cp.get_file : launch.txt : success"
                fi
                salt "$hostName" cmd.run 'diskpart /s C:\Windows\Temp\launch.txt' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskLaunch : cmd.run : diskpart : failed"
                    exit 1
                else
                    echo "DiskLaunch : cmd.run : diskpart : success"
                fi
                rm -rf $saltDataHome/$fileName\.txt
            ;;
            resize)
                mountPoint=$4
                sed "s/{mountPoint}/$mountPoint/gi" $winResizeTemplate1 >> $saltDataHome/$fileName\.bat
                salt "$hostName" cp.get_file $saltDataUrl/$fileName\.bat 'C:\Windows\Temp\resize.bat' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskResize : cp.get_file : resize.bat : failed"
                    exit 1
                else
                    echo "DiskResize : cp.get_file : resize.bat : success"
                fi
                salt "$hostName" cp.get_file $winResizeTemplate2 'C:\Windows\Temp\resize.txt' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskResize : cp.get_file : resize.txt : failed"
                    exit 1
                else
                    echo "DiskResize : cp.get_file : resize.txt : success"
                fi
                salt "$hostName" cmd.run 'diskpart /s C:\Windows\Temp\resize.bat' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskResize : cmd.run : resize.bat : failed"
                    exit 1
                else
                    echo "DiskResize : cmd.run : resize.bat : success"
                fi
                rm -rf $saltDataHome/$fileName\.bat
            ;;
            delete)
                mountPoint=$4
                sed "s/{mountPoint}/$mountPoint/gi" $winDeleteTemplate1 >> $saltDataHome/$fileName\.bat
                salt "$hostName" cp.get_file $saltDataUrl/$fileName\.bat 'C:\Windows\Temp\delete.bat' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskDelete : cp.get_file : delete.bat : failed"
                    exit 1
                else
                    echo "DiskDelete : cp.get_file : delete.bat : success"
                fi
                salt "$hostName" cp.get_file $winDeleteTemplate2 'C:\Windows\Temp\delete.txt' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskDelete : cp.get_file : delete.txt : failed"
                    exit 1
                else
                    echo "DiskDelete : cp.get_file : delete.txt : success"
                fi
                salt "$hostName" cmd.run 'diskpart /s C:\Windows\Temp\delete.bat' 2>&1 > /dev/null
                if [ "$?" -ne 0 ]; then
                    echo "DiskDelete : cmd.run : delete.bat : failed"
                    exit 1
                else
                    echo "DiskDelete : cmd.run : delete.bat : success"
                fi
                rm -rf $saltDataHome/$fileName\.bat
            ;;
            *)
                echo $usageEcho1
                echo $usageEcho2
                echo $usageEcho3
            ;;
        esac
    ;;
    *)
        echo $usageEcho1
        echo $usageEcho2
        echo $usageEcho3
    ;;

esac
exit 0
